package com.mycompany;

import org.apache.wicket.Application;
import org.apache.wicket.MetaDataKey;
import org.apache.wicket.Page;
import org.apache.wicket.atmosphere.EventBus;
import org.apache.wicket.atmosphere.ResourceRegistrationListener;
import org.apache.wicket.atmosphere.config.AtmosphereLogLevel;
import org.apache.wicket.atmosphere.config.AtmosphereTransport;
import org.apache.wicket.protocol.http.WebApplication;
import org.apache.wicket.util.lang.Bytes;

public class WicketApplication extends WebApplication {

    private MetaDataKey<com.google.common.eventbus.EventBus> GOOGLE_EVENTBUS_METADATAKEY = new MetaDataKey<com.google.common.eventbus.EventBus>() {
    };

    private EventBus eventBus;

    @Override
    public Class<HomePage> getHomePage() {
        return HomePage.class;
    }

    public EventBus getEventBus() {
        return eventBus;
    }

    public static WicketApplication get() {
        return (WicketApplication) Application.get();
    }

    @Override
    public void init() {
        super.init();
        mountPage("home.html", HomePage.class);
        
        eventBus = new EventBus(this);
        eventBus.getParameters().setTransport(AtmosphereTransport.WEBSOCKET);
        eventBus.getParameters().setFallbackTransport(AtmosphereTransport.LONG_POLLING);
        eventBus.getParameters().setLogLevel(AtmosphereLogLevel.INFO);
        eventBus.addRegistrationListener(new ResourceRegistrationListener() {

            public void resourceUnregistered(String uuid) {
                System.out.println("Unregistered " + uuid);
            }

            public void resourceRegistered(String uuid, Page page) {
                System.out.println("Registered " + uuid);
            }
        });

        getStoreSettings().setMaxSizePerSession(Bytes.kilobytes(20L));
    }

    public com.google.common.eventbus.EventBus getGoogleEventBus() {
        return getMetaData(GOOGLE_EVENTBUS_METADATAKEY);
    }
}
